Module blaxel.core.client.models.delete_sandbox_preview_token_response_200
==========================================================================

Classes
-------

`DeleteSandboxPreviewTokenResponse200(message: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Attributes:
        message (Union[Unset, str]): Success message
    
    Method generated by attrs for class DeleteSandboxPreviewTokenResponse200.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `message: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :